# pyutils
* modules are in package mcneelat.pyutils
    * anomali
    * confutils
    * crowdstrike
    * dbutils
    * digitalshadows
    * directoryutils
    * dnsutils
    * fileutils
    * kafkautils
    * netutils